🔸NISAR
========


RSLC (``nisar_rslc``)
---------------------
The `nisar_rslc` function extracts C2 matrix elements from the given NISAR RSLC `.h5` file and saves them into a C2 directory.

.. autofunction:: polsartools.nisar_rslc
   :noindex:



GSLC (``nisar_gslc``)
---------------------

The `nisar_gslc` function extracts C2 matrix elements from the given NISAR GSLC `.h5` file and saves them into a C2 directory.

.. autofunction:: polsartools.nisar_gslc
   :noindex:
